@@ -2,7 +2,7 @@
 
 """ The work time log app tracks working hours in an interaction model similar to git. """
 
-__version__: str = "0.99.0.post1"
+__version__: str = "0.99.1"
 
 import csv
 import datetime as dt
@@ -12,10 +12,10 @@ import sys
 from collections import defaultdict, namedtuple
 from dataclasses import dataclass
 from fnmatch import fnmatch
-from itertools import chain
+from itertools import chain, cycle, islice
 from typing import Callable, DefaultDict, Dict, List, Optional, Set, Tuple, cast
 
-from work_components import consts, dt_parse, util
+from work_components import consts, dt_parse, migrate, util
 from work_components.arguments import (
     ADD_NAME,
     MAINTENANCE_NAMES,
@@ -454,11 +454,7 @@ class Work:
         - switch A B -> stop at time A, start at B (e.g. after taking a break)
         - switch A -> stop at A and immediately start again (e.g. after switching tasks)
         """
-        # <MIGRATE-args> To be removed in v0.100
-        if args.mode != "switch":
-            print(
-                f'Command name "{args.mode}" is deprecated and will be removed in the upcoming version. Please use "switch" instead.'
-            )
+        migrate.warn_deprecated_switch_name(args.mode)
 
         switch_time: dt.datetime = dt_parse.resolve_time_argument(
             args.time_s,
@@ -515,6 +511,11 @@ class Work:
         if active_run_start is None:
             raise InvalidOperationWarning.cant("switch", "no run is currently active")
 
+        if active_run_start == switch_time == restart_time:
+            raise InvalidOperationWarning(
+                "Switch time is identical to the start time of the active run – did nothing.",
+            )
+
         if switch_time > restart_time:
             raise InvalidOperationWarning.cant(
                 "switch", "specified stop time needs to lie before the restart time"
@@ -635,6 +636,7 @@ class Work:
 
         minutes_left_today: float = minutes_to_work - total_minutes_worked
         minutes_left_delta_str: str = self._timedelta_str(abs(minutes_left_today))
+        prospective_start: dt.datetime = self._prospective_start(active_start)
 
         output += new_section_line()
 
@@ -646,7 +648,7 @@ class Work:
         else:
             output += "{} left (until {})".format(
                 minutes_left_delta_str,
-                (dt.datetime.now() + dt.timedelta(minutes=minutes_left_today)).strftime(
+                (prospective_start + dt.timedelta(minutes=minutes_left_today)).strftime(
                     TIME_FORMAT
                 ),
             )
@@ -662,10 +664,18 @@ class Work:
                 elif delta_yesterday < 0:
                     output += Color.color(time_str + " overtime", Color.GREEN)
 
-        if minutes_expected != 8.0 * 60:
+        if not (associated_recess := self.recess_dao.get_recess_for(today)).empty:
+            names: List[str] = []
+            if associated_recess.vacation is not None:
+                names.append("vacation day")
+            if associated_recess.holiday is not None:
+                names.append("holiday")
+            if associated_recess.reduced_hour_day is not None:
+                names.append("reduced hour day")
             output += new_section_line()
             output += (
-                "Note: Reduced hour day (" + self._timedelta_str(minutes_expected) + ")"
+                f"Note: {(' + '.join(names)).capitalize()} "
+                + f"({self._timedelta_str(minutes_expected)} expected)"
             )
 
         print(output)
@@ -697,13 +707,8 @@ class Work:
 
         start_time: Optional[dt.datetime] = self.dao.get_start_time()
 
-        # prospective_start | If start_time is None, no run is active. Then we assume
-        #                     we would start a run now.
-        prospective_start: dt.datetime = start_time or dt_parse.resolve_time_argument(
-            argument="now",
-            baseline_date=dt.date.today(),
-            rounding_mode=dt_parse.RoundingMode.DOWN,
-        )
+        # prospective_start | Either start_time or "now" (rounded)
+        prospective_start: dt.datetime = self._prospective_start(start_time)
 
         start_argument: bool = args.h_start is not None
         if start_argument:
@@ -793,6 +798,20 @@ class Work:
 
         print(f"{header}{note_str}{optional_output}{warning_str}")
 
+    def _prospective_start(self, start_time: Optional[dt.datetime]):
+        """Return prospective start for hours calculation.
+
+        If start_time is not None, it is simply returned. Otherwise, assume a run is
+        started with argument "now" and return the according start time."""
+        if start_time is not None:
+            return start_time
+
+        return dt_parse.resolve_time_argument(
+            argument="now",
+            baseline_date=dt.date.today(),
+            rounding_mode=dt_parse.RoundingMode.DOWN,
+        )
+
     @dataclass
     class HoursData:
         """ Storage container for data used in hours sub-functions. """
@@ -1278,10 +1297,6 @@ class Work:
             filter_message=args.filter_message,
         )
 
-        if not filtered_records:
-            print(self._none_found_msg(selected_days))
-            return
-
         total_minutes_worked: float = self._minutes_worked(records=filtered_records)
         output: List[str] = []
 
@@ -1289,6 +1304,10 @@ class Work:
 
         # View by category
         if args.mode == "by-category":
+            if not filtered_records:
+                print(self._none_found_msg(selected_days))
+                return
+
             view_by_category: List[str] = self.view_by_category(
                 records=filtered_records, total_minutes_worked=total_minutes_worked
             )
@@ -1363,7 +1382,7 @@ class Work:
         """ Create a view of the balance development over the given records. """
 
         if not util.is_continuous_period(period):
-            raise NotImplementedError()
+            raise NotImplementedError("Expecting continuous period!")
 
         filtered_records_by_day: Dict[dt.date, List[Record]] = defaultdict(list)
         for record in records:
@@ -1377,7 +1396,6 @@ class Work:
         total_expected: float = 0.0
         total_worked: float = 0.0
         total_balance: float = 0.0
-        max_expected: float = 0.0
 
         for day in period:
             days_records: List[Record] = filtered_records_by_day[day]
@@ -1389,12 +1407,32 @@ class Work:
             total_balance += minutes_expected - minutes_worked
 
             stored_expected, stored_worked = buckets_data[bucket_selector(day)]
-            new_expected = stored_expected + minutes_expected
             buckets_data[bucket_selector(day)] = BucketData(
-                expected=new_expected,
+                expected=stored_expected + minutes_expected,
                 worked=stored_worked + minutes_worked,
             )
-            max_expected = max(max_expected, new_expected)
+
+        # Balance graph: To properly size it, we need the maximum minutes for each side
+        typical_expected_max: float = sum(
+            # Given the typical expected minutes of a work week, sort them in reverse
+            # (largest first) and then cylce and take from the infinite list until
+            # <bucket size> elements were retrieved. Finally, sum up. Thereby, we
+            # get the "maximum" expected hours for a period of that length.
+            islice(
+                cycle(sorted(self._expected_minutes(), reverse=True)),
+                date_buckets.size,
+            )
+        )
+        max_minutes: float = max(
+            chain(
+                # maximum expected for a period of that length
+                [typical_expected_max],
+                # maximum expected this period
+                [data.expected for data in buckets_data.values()],
+                # maximum deviation from expected (maximum bar size)
+                [abs(data.expected - data.worked) for data in buckets_data.values()],
+            )
+        )
 
         prin_table: PrinTable = PrinTable(padding="  ")
         date_column_title: str = "Date range"
@@ -1419,15 +1457,21 @@ class Work:
         for b_id, b_data in buckets_data.items():
             bucket_name, bucket_range = date_buckets.descriptor(b_id)
             balance_graph: str = self._balance_graph(
-                b_data.expected, b_data.worked, max_expected
+                b_data.expected, b_data.worked, max_minutes
             )
+            expected_str = self._timedelta_str(b_data.expected)
+            worked_str = self._timedelta_str(b_data.worked)
+            if b_data.expected == 0.0:
+                expected_str = "-"
+            if b_data.worked == 0.0:
+                worked_str = "-"
             prin_table.add_row(
                 [
                     f"{bucket_name}",
                     f"{bucket_range}",
                     f"{len(date_buckets.mapped_dates[b_id])}",
-                    f"{self._timedelta_str(b_data.expected)}",
-                    f"{self._timedelta_str(b_data.worked)}",
+                    expected_str,
+                    worked_str,
                     f"{balance_graph}",
                 ]
             )
@@ -1459,13 +1503,13 @@ class Work:
                 raise ValueError("DateBuckets requires continuous date period.")
             self._period: List[dt.date] = period
             self.name: str
-            self._compute_selector_and_name()
+            self._set_name()
 
             self.mapped_dates: Dict[str, List[dt.date]]  # contained dates
             self._map_dates()
 
-        def _compute_selector_and_name(self) -> None:
-            """ Based on the period, set selector and name. """
+        def _set_name(self) -> None:
+            """ Based on the period, set name. """
             self.name = "month"
             if len(self._period) < 7 * 16:
                 self.name = "week"
@@ -1478,6 +1522,15 @@ class Work:
             for day in self._period:
                 self.mapped_dates[self.to_selector(day)].append(day)
 
+        @property
+        def size(self) -> int:
+            """ Return the (maximum) length of each bucket in days. """
+            return {
+                "day": 1,
+                "week": 7,
+                "month": 31,
+            }[self.name]
+
         def to_selector(self, given_date: dt.date) -> str:
             """ Transform given date to bucket selector. """
             formatter: str = {
@@ -1522,7 +1575,7 @@ class Work:
             )
 
     @staticmethod
-    def _balance_graph(expected: float, worked: float, max_expected: float) -> str:
+    def _balance_graph(expected: float, worked: float, max_minutes: float) -> str:
         """Create a 2D balance graph to visualize over- or undertime.
         Example: |  ===|     |"""
         side_length: int = 8
@@ -1532,7 +1585,7 @@ class Work:
         brd: str = "|"
 
         deviation: float = expected - worked
-        percent_deviation: float = abs(deviation / max_expected)
+        percent_deviation: float = abs(deviation / max_minutes)
         if percent_deviation < 0.05:
             return f"{brd}{unbroken_side}{ctr}{unbroken_side}{brd}"
 
@@ -1832,7 +1885,7 @@ class Work:
     def _list_recess_days(self, year: int) -> None:
         """ List recess days of the given year. """
         if not self.recess_dao.has_days(year=year):
-            print(f"No recess days stored for {year}.")
+            print(f"No free days stored for {year}.")
             return
         if holidays := self.recess_dao.get_holidays(year=year):
             print("Holidays:")
@@ -2040,27 +2093,32 @@ class Work:
         timedelta_str: str = self._timedelta_str(abs(minutes))
         return timedelta_str, sign
 
-    def _minutes_per_days(self, days: List[dt.date]) -> List[Tuple[dt.date, float]]:
-        """ Return a list of the minutes to work on each day. """
-
-        # This method is the single place where expected hours are calculated.
-        # That means that we only need to consider vacations or holidays here.
-
-        result: List[Tuple[dt.date, float]] = []
+    def _expected_minutes(self) -> List[float]:
+        """ Return a list of minutes to work on a regular week. """
         normal_hours: List[float] = (
             list(self.configuration.expected_hours.values())
             if self.configuration.expected_hours
             else [8.0] * 5 + [0.0] * 2
         )
         assert len(normal_hours) == 7
+        return [hour * 60.0 for hour in normal_hours]
+
+    def _minutes_per_days(self, days: List[dt.date]) -> List[Tuple[dt.date, float]]:
+        """ Return a list of the minutes to work on the given days. """
+
+        # This method is the single place where expected hours are calculated.
+        # That means that we only need to consider vacations or holidays here.
+
+        result: List[Tuple[dt.date, float]] = []
+        normal_minutes: List[float] = self._expected_minutes()
 
         for day in days:
             # We don't need the list index of the day, but its relative "index" in its week.
-            hours = normal_hours[day.weekday()]
+            minutes = normal_minutes[day.weekday()]
             # If a day is added twice, this always returns the lowest hour value.
             if (reduced_hours := self.recess_dao.reduced_hours(day)) is not None:
-                hours = reduced_hours
-            result.append((day, hours * 60.0))
+                minutes = reduced_hours * 60.0
+            result.append((day, minutes))
 
         return result
 
