@@ -7,6 +7,7 @@ import textwrap
 from typing import Dict, List, Optional, Union
 
 from work_components import consts
+from work_components.util import Color
 
 NAME = "work"
 
@@ -78,9 +79,9 @@ class Mode:
 
 
 MODES: Dict[str, Mode] = {
-    START_NAME: Mode(START_NAME, help_text="Start the protocol"),
-    STOP_NAME: Mode(STOP_NAME, help_text="Stop the protocol"),
-    ADD_NAME: Mode(ADD_NAME, help_text="Add a protocol entry"),
+    START_NAME: Mode(START_NAME, help_text="Start work"),
+    STOP_NAME: Mode(STOP_NAME, help_text="Stop work"),
+    ADD_NAME: Mode(ADD_NAME, help_text="Add a log entry"),
     SWITCH_NAMES[0]: Mode(
         SWITCH_NAMES,
         help_text="Short-hand for stop & start",
@@ -97,15 +98,15 @@ MODES: Dict[str, Mode] = {
     HOURS_NAMES[0]: Mode(HOURS_NAMES, help_text="Calculate hours worked"),
     LIST_NAMES[0]: Mode(
         LIST_NAMES,
-        help_text="List protocol records",
+        help_text="List work records",
         description=(
-            "List protocol records (by default the current day)."
+            "List work records (by default the current day)."
             " For other ranges use the optional arguments."
         ),
     ),
     DAY_NAME: Mode(
         DAY_NAME,
-        help_text="List the current day with all details.",
+        help_text="List the current day with all details",
         description=(
             "List the current day with all details. Shorthand for "
             '"list --include-active --with-breaks --list-empty"'
@@ -113,27 +114,27 @@ MODES: Dict[str, Mode] = {
     ),
     VIEW_NAME: Mode(
         VIEW_NAME,
-        help_text="Views on protocol records",
+        help_text="Views on work records",
         description=(
-            "View protocol records (by default the current day). "
-            "Similar to list, but summarizes by aspects other than date."
+            "Views on work records (by default of the current day). "
+            "Similar to list, but groups by aspects other than date."
         ),
     ),
-    EXPORT_NAME: Mode(EXPORT_NAME, help_text="Export records as CSV."),
+    EXPORT_NAME: Mode(EXPORT_NAME, help_text="Export records as CSV"),
     EDIT_NAMES[0]: Mode(
         EDIT_NAMES,
-        help_text="Edit protocol records",
-        description="Edit protocol records (by default from the current day)",
+        help_text="Edit work records",
+        description="Edit work records (by default from the current day)",
     ),
     REMOVE_NAMES[0]: Mode(
         REMOVE_NAMES,
-        help_text="Remove records from the protocol",
-        description="Remove records from the protocol (by default from the current day)",
+        help_text="Remove records from the log",
+        description="Remove records from the log (by default from the current day)",
     ),
     RECESS_NAMES[0]: Mode(
         RECESS_NAMES,
-        help_text="Manage free days (vacation, holidays, ...)",
-        description="Manage free days (vacation, holidays, ...). Default mode: --list",
+        help_text="Manage free days (vacation, holidays, part-time days)",
+        description="Manage free days (vacation, holidays, part-time days). Default mode: --list",
     ),
     CONFIG_NAME: Mode(
         CONFIG_NAME, help_text="Check and interact with the configuration"
@@ -153,14 +154,15 @@ class Arguments:
 
         parser = argparse.ArgumentParser(
             prog=NAME,
+            description="Time tracking with an interaction model inspired by git.",
             epilog="To find out more, check the help page of individual modes.",
         )
         # fmt: off
         parser.add_argument("-H", "--help-verbose", action="store_true",
-            help="A longer help output, similar to a man page.")
+            help="show a longer help output, similar to a man page")
         parser.add_argument("-V", "--version", action="version", version=f"%(prog)s {version}")
-        parser.add_argument("-d", "--debug", action="store_true", help="Use a debug directory")
-        parser.add_argument("-y", "--dry-run", action="store_true", help="Only print output")
+        parser.add_argument("-d", "--debug", action="store_true", help="use a debug directory")
+        parser.add_argument("-y", "--dry-run", action="store_true", help="only print output")
         # fmt: on
 
         modes = parser.add_subparsers(title="modes", dest="mode")
@@ -490,7 +492,7 @@ class Arguments:
             type=int,
             nargs="?",
             const=dt.date.today().year,
-            help="List recess days of YEAR (default: current year)",
+            help="List free days of YEAR (default: current year)",
         )
 
         # MAINTENANCE modes
@@ -545,15 +547,17 @@ class Arguments:
         )
         new_epilog = lambda t, c: "\n\n" + t + ":\n" + "\n".join(map(fill, c))
 
+        print("\n\n" + Color.bold("EXTENDED HELP"), end="")
+
         # fmt: off
         print(
             new_epilog(
                 t="rounding",
                 c=[
                     "Times are rounded in your favor, to the next full 15 minutes, when"
-                        " you enter 'now' instead of an exact time. For example:",
-                    "- 'work start now' at 10:14 starts at 10:00",
-                    "- 'work stop now' at  19:01 stops at  19:15",
+                        ' you enter "now" instead of an exact time. For example:',
+                    '- "work start now" at 10:14 starts at 10:00',
+                    '- "work stop now" at 19:01 stops at 19:15',
                 ],
             )
             + new_epilog(
@@ -561,10 +565,12 @@ class Arguments:
                 c=[
                     "For some sub-functions (mainly status and hours), you will be nudged to work "
                         "no more, but also no less, than the expected hours. By default, work will "
-                        "expect 8 hours for every workday (Mon–Fri). Two ways exist to define days "
-                        "where less hours should be expected:",
-                    '- holidays: In the RC file, you can define days as "reduced_hour_days"',
-                    "- vacation: Use work vacation --add to add vacation days (expect 0 hours)",
+                        "expect 8 hours for every workday (Mon–Fri). Change the default by editing "
+                        "the run-time configuration. To define individual days where less hours "
+                        "should be expected, use the free-days command:",
+                    "- free-days --add-vacation for vacations (expect 0 hours)",
+                    '- free-days --add-holiday for public holidays (expect 0 hours)"',
+                    '- free-days --add-reduced-day for part-time days (expect < 8 hours)"',
                 ],
             )
             + new_epilog(
@@ -572,11 +578,11 @@ class Arguments:
                 c=[
                     "Based on the expected hours and the time worked, two balances are "
                         "calculated:",
-                    "1) Week balance (shown in status): Total over-/undertime "
-                        "accumulated over the current week (starting Monday), up to "
-                        "the day before today.",
-                    "2) Current balance (shown in hours --balance): This shows "
-                        "the hours you need to work that day and how many are remaining.",
+                    "1) Week balance (shown in status): Total over-/undertime accumulated over "
+                        "the current week (starting Monday), up to the day before today.",
+                    "2) Current balance (shown in hours): This shows the hours you need to work "
+                        "on the current day and how many are remaining.",
+                    'To check your balance development over other periods, use "view balance."'
                 ],
             )
         )
