@@ -12,7 +12,7 @@ import shutil
 import tempfile
 from typing import Iterable, List, Optional
 
-from work_components import util
+from work_components import migrate, util
 from work_components.consts import (
     DATETIME_FORMAT,
     DAY_FILE_PATTERN,
@@ -156,13 +156,7 @@ class Record:
         Parse one row of a protocol file in the form of
         ["start", "end", "category", "message"].
         """
-
-        # <MIGRATE-v2-to-v3> functionality. To be removed in v1!
-        if len(row) == 2:
-            raise IOError(
-                "Detected old protocol version. "
-                "Please migrate using v0.93 and then try again."
-            )
+        migrate.raise_old_protocol_version(row)
 
         if len(row) != 4:
             raise Record.CorruptedProtocolRowError(
