@@ -6,7 +6,7 @@ import re
 from enum import Enum
 from typing import List, Optional, Tuple
 
-from work_components import consts, util
+from work_components import util
 
 
 class RoundingMode(Enum):
@@ -117,29 +117,32 @@ def resolve_day_argument(argument: str) -> dt.date:
     last_seven_days: List[dt.date] = util.get_period(
         period_start=today - dt.timedelta(days=6), period_end=today
     )
-    indices: List[int] = [d.weekday() for d in last_seven_days]
-    day_names: List[str] = [d.lower() for d in consts.WEEKDAYS]
-    # Build a list of the last seven weekday names in the order they appeared (ending today).
-    day_names = [day_names[i] for i in indices]
+    # Double-check that we have selected a full week
+    assert sorted([d.weekday() for d in last_seven_days]) == list(range(7))
+
+    match: Optional[dt.date] = None
+    argument = argument.casefold()
+    for day in last_seven_days:
+        day_name: str = day.strftime("%A").casefold()
 
-    match: Tuple[int, float] = (0, 0.0)
-    argument = argument.lower()
-    for day_name in day_names:
         # Full match
         if argument == day_name:
-            match = (day_names.index(day_name), 1.0)
-            break
-        # Partial match, e. g. "mon" for "monday" -> 50 %
-        elif day_name.startswith(argument):
-            new_match = len(day_name) / len(argument)
-            if new_match > match[1]:
-                match = (day_names.index(day_name), new_match)
-    if match[1] == 0.0:
-        raise ValueError("Given argument does not match anything")
+            return day
 
-    # Match with weekday with same index
-    day_index = match[0]
-    return last_seven_days[day_index]
+        # No match
+        if not day_name.startswith(argument):
+            continue
+
+        # Partial match: only accept if unambiguous
+        if match is not None:
+            raise ValueError(
+                f'Argument "{argument}" matches more than one day of the week'
+            )
+        match = day
+
+    if match is None:
+        raise ValueError(f'Argument "{argument}" does not match any day of the week')
+    return match
 
 
 def parse_date_str(argument: str) -> dt.date:
